/* -*- Mode: C; c-basic-offset: 4 -*- */
/* GTK DBF Editor -- a simple dbf editor built with GTK+
 * Copyright (C) 2001 Steffen Macke
 *
 * table.c: display dbf table
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <gtk/gtk.h>
#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <stdlib.h>

#include "interface.h"
#include "support.h"
#include "shapefil.h"
#include "dbf.h"
#include "table.h"

void dbf_create_table() {
  GtkWidget *scrolledwindow1;
  GtkWidget *clist1;
  GtkWidget *label1;

   int n_fields;
   int i;
   char field_name[12];
   int n_field_width;

   if(table_window == NULL) {
       table_window = create_table_window();
   }
   n_fields = DBFGetFieldCount(dbfh_file);

   scrolledwindow1 = lookup_widget(table_window, "scrolledwindow1");
   
   clist1 = gtk_clist_new (n_fields);
   gtk_widget_ref (clist1);
   gtk_object_set_data_full (GTK_OBJECT (table_window), "clist1", clist1,
                            (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (clist1);
   gtk_container_add (GTK_CONTAINER (scrolledwindow1), clist1);
   for(i=0;i<n_fields;i++) {
       gtk_clist_set_column_width (GTK_CLIST (clist1), 1, 80);
   }

   gtk_clist_column_titles_show (GTK_CLIST (clist1));

   for(i=0; i<n_fields; i++) {
       DBFGetFieldInfo(dbfh_file, i, field_name, &n_field_width, NULL);
       label1 = gtk_label_new (field_name);
       gtk_widget_ref (label1);
       gtk_object_set_data_full (GTK_OBJECT (table_window), field_name, label1,
                            (GtkDestroyNotify) gtk_widget_unref);
       gtk_widget_show (label1);
       gtk_clist_set_column_widget (GTK_CLIST (clist1), i, label1);
   }

   gtk_signal_connect (GTK_OBJECT (clist1), "select_row",
		       GTK_SIGNAL_FUNC (on_clist1_select_row),
		       NULL);

}


void
on_clist1_select_row                   (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
    if(row == n_current_record) {
	return;
    }
    dbf_display_record(dbf_editor_window, row);
}

void dbf_fill_table() {
    GtkWidget *clist1;
    int i, j;
    int n_fields;
    int n_record_count;
    gchar *field_attribute;
    gchar **record;

    if(table_window == NULL) {
	return;
    }

    if(DBFGetRecordCount(dbfh_file) == 0) {
	return;
    }
    clist1 = lookup_widget(table_window, "clist1");
    
    n_fields = DBFGetFieldCount(dbfh_file);
    record = (gchar **)g_new(gchar*, n_fields);
    n_record_count = DBFGetRecordCount(dbfh_file);
    for(j=0; j<n_record_count; j++) {
	for(i = 0; i< n_fields; i++) {
	    field_attribute = (gchar *)DBFReadStringAttribute(dbfh_file, j, i);
	    record[i] = g_strdup(field_attribute);
	}
	gtk_clist_append(GTK_CLIST(clist1), record);
	for(i=0; i<n_fields; i++) {
	    g_free(record[i]);
	}
    }
    g_free(record);
}

void dbf_table_add_row() {
    GtkWidget *clist1;
    int n_fields;
    gchar **record;
    int i;
    
    if(table_window == NULL) {
	return;
    }
    
    n_fields = DBFGetFieldCount(dbfh_file);
    record = (gchar **)g_new(gchar *, n_fields);
    for(i=0; i<n_fields; i++) {
	record[i] = g_strdup("");
    }
    clist1 = lookup_widget(table_window, "clist1");
    if(clist1 == NULL) {
	return;
    }
    gtk_clist_append(GTK_CLIST(clist1), record);
    g_free(record);
}

void dbf_table_select_row(gint row) {
    GtkWidget *clist1;

    if(table_window == NULL) {
	return;
    }

    clist1 = lookup_widget(table_window, "clist1");

    gtk_clist_select_row(GTK_CLIST(clist1), row, 0);
    gtk_clist_moveto(GTK_CLIST(clist1),row, 0, 0, 0);
}

void dbf_table_set_cell_value(gchar *value, gint column, gint row) {
    GtkWidget *clist1;

    if(table_window == NULL) {
	return;
    }

    clist1 = lookup_widget(table_window, "clist1");

    gtk_clist_set_text(GTK_CLIST(clist1), row, column, value);
}












